pyhsm.aead_cmd.YHSM_Cmd_AEAD_Buffer_Generate

Package pyhsm :: Module aead_cmd :: Class YHSM_Cmd_AEAD_Buffer_Generate |
[frames] | no frames]

# Class YHSM_Cmd_AEAD_Buffer_Generate

    cmd.YHSM_Cmd --+
                   |
       YHSM_AEAD_Cmd --+
                       |
                      YHSM_Cmd_AEAD_Buffer_Generate

Generate AEAD block of data buffer for a specific key.

After a key has been loaded into the internal data buffer, this command can be used a number of times to get AEADs of the data buffer for different key handles.

For example, to encrypt a YubiKey secrets to one or more Yubico KSM's that all have a YubiHSM attached to them.

Key handle (and system flags) permission flags required for this operation : YSM_BUFFER_AEAD_GENERATE YSM_BUFFER_LOAD if non-random data has been loaded into the internal buffer

Instance Methods
__init__(self, stick, nonce, key_handle) The base class for all YSM_ commands. |
Inherited from `YHSM_AEAD_Cmd`: `__repr__`, `parse_result` Inherited from `cmd.YHSM_Cmd`: `execute`

Class Variables
Inherited from `YHSM_AEAD_Cmd`: `key_handle`, `nonce`, `response`, `status` Inherited from `cmd.YHSM_Cmd`: `executed`, `response_status`

Method Details

### __init__(self, stick, nonce, key_handle) (Constructor) |
The base class for all YSM_ commands. Parameters: `stick` - Reference to a YubiHSM `command` - The YSM_xxx command defined in pyhsm.defines. `payload` - a packed C struct, represented as a Python string Overrides: cmd.YHSM_Cmd.__init__ (inherited documentation)